Djecrety
========
.. image:: https://img.shields.io/pypi/v/djecrety.svg
  :target: https://pypi.org/project/djecrety

.. image:: https://github.com/mrouhi13/djecrety/workflows/Django%20CI/badge.svg
  :target: https://github.com/mrouhi13/djecrety/workflows/Django%20CI

.. image:: https://readthedocs.org/projects/djecrety/badge/?version=latest
  :target: https://djecrety.readthedocs.io/?badge=latest
  :alt: Documentation Status

.. image:: https://codecov.io/gh/mrouhi13/djecrety/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/mrouhi13/djecrety

.. image:: https://img.shields.io/pypi/dm/djecrety.svg
  :target: https://pypistats.org/packages/djecrety
  :alt: PyPI - Downloads

Djecrety is a Django implementation of a `Web tool <https://djecrety.ir/>`_ with the same name. This package provides a command to generate a new secret key for your project and save it to ``settings.py``.

For more details `http://djecrety.readthedocs.io <http://djecrety.readthedocs.io>`_

Requirements
============
To be able to run **Djecrety** you have to meet following requirements:

- Python (3.5, 3.6, 3.7)
- Django (2.0, 2.1, 2.2)

Bear in mind that for Django-2.x you will need at least Python 3.5

Installation
============
Simply install using ``pip``:

.. code-block:: bash

    $ pip install djecrety

Documentation
=============
Documentation is available on `http://djecrety.readthedocs.io <http://djecrety.readthedocs.io>`_.
